@@ -24,6 +24,8 @@ function(corpus, keywords, model, voc = "none", vocformat = "")
         unlink(tmpdir, recursive = TRUE)
     })
 
+    model <- file.path(normalizePath(dirname(model)), basename(model))
+
     ## KEA can use vocabularies in format skos or text.
     ## In these case, we need to check for the existence of all voc
     ## files needed by KEA (otherwise, it will call System.exit(1)), and
@@ -88,9 +90,40 @@ function(corpus, keywords, model, voc = "none", vocformat = "")
 extractKeywords <-
 function(corpus, model, voc = "none", vocformat = "")
 {
+    cwd <- getwd()
     tmpdir <- tempfile()
     dir.create(tmpdir)
-    on.exit(unlink(tmpdir, recursive = TRUE))
+    on.exit({
+        setwd(cwd)
+        unlink(tmpdir, recursive = TRUE)
+    })
+
+    model <- file.path(normalizePath(dirname(model)), basename(model))    
+
+    ## See createModel().
+    vocfiles <- character()
+    if(identical(vocformat, "skos")) {
+        vocfiles <- paste0(voc, ".rdf")
+        if(!file.exists(vocfiles))
+            stop(sprintf("Vocabulary file '%s' does not exist.",
+                         vocfiles))
+
+    } else if(identical(vocformat, "text")) {
+        vocfiles <- paste0(voc, c(".en", ".rel", ".use"))
+        if(length(pos <- which(!file.exists(vocfiles))))
+            stop(sprintf("Vocabulary file '%s' does not exist.",
+                         vocfiles[pos[1L]]))
+    }
+    if(length(vocfiles)) {
+        vocdir <- file.path(RKEA_work_dir, "VOCABULARIES")
+        dir.create(vocdir)
+        on.exit(unlink(vocdir, recursive = TRUE), add = TRUE)
+        file.copy(vocfiles, vocdir)
+        voc <- basename(voc)
+    }
+    
+    setwd(RKEA_work_dir)
+
     writeCorpus(corpus, path = tmpdir,
                 filenames = sprintf("%s.txt", seq_along(corpus)))
     
